@@ -49,7 +49,7 @@ GOLD_DB_NAME = f"cortex_databricks_gold_{ENVIRONMENT}"
 
 def __verify_parameters(function):
     def wrapper(*args, **kwargs):
-        insert_modes_avalables = ["append", "upsert"]
+        insert_modes_avalables = ["append", "upsert", "overwrite"]
         insert_mode = kwargs.get("insert_mode", "append")
         if  insert_mode in insert_modes_avalables:
              return function(*args, **kwargs)
@@ -252,7 +252,7 @@ def __write_function(
     else:
         micro_batch_df.write.option("header", "true").option(
             "mergeSchema", "true"
-        ).partitionBy(*partition_columns).format("delta").mode("append").saveAsTable(
+        ).partitionBy(*partition_columns).format("delta").mode(insert_mode).saveAsTable(
             table_name
         )
         spark.sql(f"ALTER TABLE {table_name} OWNER TO `data-platform`")
@@ -423,7 +423,7 @@ def landing_to_bronze(
     infer_schema=False,
     reset_checkpoint=False,
     catalog_name=None,
-    db_name=None,
+    output_db_name=None,
     tbl_properties=None,
 ):
     """
@@ -442,7 +442,7 @@ def landing_to_bronze(
     :param infer_schema: flag that indicates if the schema will be infered by spark
     :param reset_checkpoint: flag that indicates if the Autoloader checkpoint will be deleted
     :param catalog_name: unity catalog name
-    :param db_name: database where the data will be written
+    :param output_db_name: database where the data will be written
     :param tbl_properties: properties to add to table
     :return:
     """
@@ -456,8 +456,8 @@ def landing_to_bronze(
             data_pack_name=data_pack_name,
             dataset_name=dataset_name,
         )
-    if db_name is None:
-        db_name = BRONZE_DB_NAME
+    if output_db_name is None:
+        output_db_name = BRONZE_DB_NAME
 
     if type(schema_path_or_struct_schema) == str:
         schema = get_schema_from_s3(schema_path_or_struct_schema)
@@ -495,12 +495,12 @@ def landing_to_bronze(
         dataset_name=dataset_name,
     )
 
-    db_name = f"{catalog_name}.{db_name}"
+    db_name = f"{catalog_name}.{output_db_name}"
 
     stream = write_table(
         df,
         checkpoint_location=checkpoint_location,
-        db_name=BRONZE_DB_NAME,
+        db_name=db_name,
         table_name=dataset_name,
         insert_mode=insert_mode,
         spark=spark,
@@ -518,7 +518,7 @@ def landing_to_bronze(
 
     if profiling:
         stream.awaitTermination()
-        df = spark.read.table(f"{BRONZE_DB_NAME}.{dataset_name}")
+        df = spark.read.table(db_table)
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
     return True
@@ -529,7 +529,8 @@ def bronze_to_silver(
     data_pack_name,
     dataset_name,
     insert_mode,
-    input_db_name=BRONZE_DB_NAME,
+    input_db_name=None,
+    output_db_name=None,
     partition_columns=None,
     spark=None,
     write_options: dict = None,
@@ -538,6 +539,8 @@ def bronze_to_silver(
     processing_function_kwargs=None,
     profiling=False,
     reset_checkpoint=False,
+    catalog_name=None,
+    where=None
 ):
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
@@ -553,7 +556,22 @@ def bronze_to_silver(
     if insert_mode is None:
         insert_mode = "append"
 
-    df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
+    if input_db_name is None:
+        input_db_name = BRONZE_DB_NAME
+
+    if output_db_name is None:
+        output_db_name = SILVER_DB_NAME
+
+    if catalog_name is None:
+        catalog_name = "hive_metastore"
+
+    if os.getenv("ENVIRONMENT") != "LOCAL":
+        spark.sql(f"USE CATALOG {catalog_name}")
+
+    input_db_name = f"{catalog_name}.{input_db_name}"
+    output_db_name = f"{catalog_name}.{output_db_name}"
+
+    df = read_table(spark, db_name=input_db_name, table_name=input_table_name, where=where)
     df = apply_processing_function(
         df=df,
         func=processing_function,
@@ -570,7 +588,7 @@ def bronze_to_silver(
     stream = write_table(
         df,
         checkpoint_location=checkpoint_location,
-        db_name=SILVER_DB_NAME,
+        db_name=output_db_name,
         table_name=dataset_name,
         insert_mode=insert_mode,
         spark=spark,
@@ -580,7 +598,7 @@ def bronze_to_silver(
 
     if profiling:
         stream.awaitTermination()
-        df = spark.read.table(f"{SILVER_DB_NAME}.{dataset_name}")
+        df = spark.read.table(f"{output_db_name}.{dataset_name}")
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
 
@@ -590,7 +608,8 @@ def silver_to_gold(
     data_pack_name,
     dataset_name,
     insert_mode,
-    input_db_name=SILVER_DB_NAME,
+    input_db_name=None,
+    output_db_name=None,
     partition_columns=None,
     spark=None,
     write_options: dict = None,
@@ -601,6 +620,8 @@ def silver_to_gold(
     sort_fields: list = None,
     upsert_fields: list = None,
     reset_checkpoint=False,
+    catalog_name=None,
+    where=None
 ):
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
@@ -608,6 +629,20 @@ def silver_to_gold(
         partition_columns = list()
     if upsert_fields is None:
         upsert_fields = ["cortex_id"]
+    if input_db_name is None:
+        input_db_name = SILVER_DB_NAME
+    if output_db_name is None:
+        output_db_name=GOLD_DB_NAME
+
+    if catalog_name is None:
+        catalog_name = "hive_metastore"
+
+    if os.getenv("ENVIRONMENT") != "LOCAL":
+        spark.sql(f"USE CATALOG {catalog_name}")
+
+    input_db_name = f"{catalog_name}.{input_db_name}"
+    output_db_name = f"{catalog_name}.{output_db_name}"
+
     if sort_fields is None:
         sort_fields = get_table_partitions(
             spark=spark, db_name=input_db_name, table_name=input_table_name
@@ -622,7 +657,7 @@ def silver_to_gold(
     if insert_mode is None:
         insert_mode = "append"
 
-    df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
+    df = read_table(spark, db_name=input_db_name, table_name=input_table_name, where=where)
     df = apply_processing_function(
         df=df,
         func=processing_function,
@@ -639,7 +674,7 @@ def silver_to_gold(
     stream = write_table(
         df,
         checkpoint_location=checkpoint_location,
-        db_name=GOLD_DB_NAME,
+        db_name=output_db_name,
         table_name=dataset_name,
         insert_mode=insert_mode,
         spark=spark,
@@ -651,14 +686,14 @@ def silver_to_gold(
 
     if profiling:
         stream.awaitTermination()
-        df = spark.read.table(f"{GOLD_DB_NAME}.{dataset_name}")
+        df = spark.read.table(f"{output_db_name}.{dataset_name}")
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
 
 def gold_to_kafka(
     input_table_name,
     topic_name,
-    input_db_name=GOLD_DB_NAME,
+    input_db_name=None,
     spark=None,
     write_options: dict = None,
     kafka_security_protocol="SSL",
@@ -667,6 +702,8 @@ def gold_to_kafka(
     processing_function_args=None,
     processing_function_kwargs=None,
     reset_checkpoint=False,
+    catalog_name=None,
+    where=None
 ):
     topics = [topic_name]
     create_topics_if_not_exists(
@@ -681,8 +718,16 @@ def gold_to_kafka(
         )
     if write_options is None:
         write_options = dict()
+    if input_db_name is None:
+        input_db_name = GOLD_DB_NAME
+    if catalog_name is None:
+        catalog_name = "hive_metastore"
+    if os.getenv("ENVIRONMENT") != "LOCAL":
+        spark.sql(f"USE CATALOG {catalog_name}")
 
-    df = read_table(spark, db_name=input_db_name, table_name=input_table_name)
+    input_db_name = f"{catalog_name}.{input_db_name}"
+
+    df = read_table(spark, db_name=input_db_name, table_name=input_table_name, where=where)
     df = apply_processing_function(
         df=df,
         func=processing_function,
